package javax.print.attribute;

import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.HashMap;
import java.io.Serializable;

public class HashAttributeSet implements AttributeSet, Serializable
{
    private static final long serialVersionUID = 5311560590283707917L;
    private Class myInterface;
    private transient HashMap attrMap;
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        Attribute[] array = this.toArray();
        objectOutputStream.writeInt(array.length);
        for (int i = 0; i < array.length; ++i) {
            objectOutputStream.writeObject(array[i]);
        }
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws ClassNotFoundException, IOException {
        objectInputStream.defaultReadObject();
        this.attrMap = new HashMap();
        for (int int1 = objectInputStream.readInt(), i = 0; i < int1; ++i) {
            this.add((Attribute)objectInputStream.readObject());
        }
    }
    
    public HashAttributeSet() {
        this(Attribute.class);
    }
    
    public HashAttributeSet(Attribute attribute) {
        this(attribute, Attribute.class);
    }
    
    public HashAttributeSet(Attribute[] array) {
        this(array, Attribute.class);
    }
    
    public HashAttributeSet(AttributeSet set) {
        this(set, Attribute.class);
    }
    
    protected HashAttributeSet(Class<?> myInterface) {
        this.attrMap = new HashMap();
        if (myInterface == null) {
            throw new NullPointerException("null interface");
        }
        this.myInterface = myInterface;
        return;
    }
    
    protected HashAttributeSet(Attribute attribute, Class<?> myInterface) {
        this.attrMap = new HashMap();
        if (myInterface == null) {
            throw new NullPointerException("null interface");
        }
        this.myInterface = myInterface;
        this.add(attribute);
        return;
    }
    
    protected HashAttributeSet(Attribute[] array, Class<?> myInterface) {
        this.attrMap = new HashMap();
        if (myInterface == null) {
            throw new NullPointerException("null interface");
        }
        this.myInterface = myInterface;
        for (int n = (array == null) ? 0 : array.length, i = 0; i < n; ++i) {
            this.add(array[i]);
        }
        return;
    }
    
    protected HashAttributeSet(AttributeSet set, Class<?> myInterface) {
        this.attrMap = new HashMap();
        this.myInterface = myInterface;
        if (set != null) {
            Attribute[] array = set.toArray();
            for (int n = (array == null) ? 0 : array.length, i = 0; i < n; ++i) {
                this.add(array[i]);
            }
        }
    }
    
    @Override
    public Attribute get(Class<?> clazz) {
        return (Attribute)this.attrMap.get(AttributeSetUtilities.verifyAttributeCategory(clazz, Attribute.class));
    }
    
    @Override
    public boolean add(Attribute attribute) {
        return !attribute.equals(this.attrMap.put(attribute.getCategory(), AttributeSetUtilities.verifyAttributeValue(attribute, this.myInterface)));
    }
    
    @Override
    public boolean remove(Class<?> key) {
        return key != null && AttributeSetUtilities.verifyAttributeCategory(key, Attribute.class) != null && this.attrMap.remove(key) != null;
    }
    
    @Override
    public boolean remove(Attribute attribute) {
        return attribute != null && this.attrMap.remove(attribute.getCategory()) != null;
    }
    
    @Override
    public boolean containsKey(Class<?> key) {
        return key != null && AttributeSetUtilities.verifyAttributeCategory(key, Attribute.class) != null && this.attrMap.get(key) != null;
    }
    
    @Override
    public boolean containsValue(Attribute attribute) {
        return attribute != null && attribute instanceof Attribute && attribute.equals(this.attrMap.get(attribute.getCategory()));
    }
    
    @Override
    public boolean addAll(AttributeSet set) {
        Attribute[] array = set.toArray();
        boolean n = false;
        for (int i = 0; i < array.length; ++i) {
            Attribute verifyAttributeValue = AttributeSetUtilities.verifyAttributeValue(array[i], this.myInterface);
            n = (!verifyAttributeValue.equals(this.attrMap.put(verifyAttributeValue.getCategory(), verifyAttributeValue)) || n);
        }
        return n;
    }
    
    @Override
    public int size() {
        return this.attrMap.size();
    }
    
    @Override
    public Attribute[] toArray() {
        Attribute[] array = new Attribute[this.size()];
        this.attrMap.values().toArray(array);
        return array;
    }
    
    @Override
    public void clear() {
        this.attrMap.clear();
    }
    
    @Override
    public boolean isEmpty() {
        return this.attrMap.isEmpty();
    }
    
    @Override
    public boolean equals(Object o) {
        if (o == null || !(o instanceof AttributeSet)) {
            return false;
        }
        AttributeSet set = (AttributeSet)o;
        if (set.size() != this.size()) {
            return false;
        }
        Attribute[] array = this.toArray();
        int i = 0;
        while (i < array.length) {
            if (!set.containsValue(array[i])) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    @Override
    public int hashCode() {
        int n = 0;
        Attribute[] array = this.toArray();
        for (int i = 0; i < array.length; ++i) {
            n += array[i].hashCode();
        }
        return n;
    }
}
